bayespy.nodes.GaussianGammaISO.initialize_from_parameters
=========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGammaISO.initialize_from_parameters